@@ -16,21 +16,17 @@ def tonumpy(poly):
             Numpy array.
 
     Raises:
-        ValueError:
+        numpoly.baseclass.FeatureNotSupported:
             Only constant polynomials can be cast to numpy.ndarray.
 
     Examples:
         >>> numpoly.tonumpy(numpoly.polynomial([1, 2]))
         array([1, 2])
-        >>> numpoly.tonumpy(numpoly.symbols("x"))
-        Traceback (most recent call last):
-            ...
-        ValueError: only constant polynomials can be converted to array.
 
     """
     poly = numpoly.aspolynomial(poly)
     if not poly.isconstant():
-        raise ValueError(
+        raise numpoly.FeatureNotSupported(
             "only constant polynomials can be converted to array.")
     idx = numpy.argwhere(numpy.all(poly.exponents == 0, -1)).item()
     if poly.size:
